/*
 *  playlist-ogg.h
 *  mod_musicindex
 *
 *  $Id: playlist-vorbis.h 742 2007-04-23 13:15:36Z varenet $
 *
 *  Created by Regis BOUDIN on Thu Jan 22 2004.
 *  Copyright (c) 2003-2004 Regis BOUDIN
 *  Copyright (c) 2003-2004 Thibaut VARENE
 *   
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License version 2.1,
 *  as published by the Free Software Foundation.
 *
 */
 
#ifndef PLAYLIST_OGG_H
#define PLAYLIST_OGG_H

#include "mod_musicindex.h"

mu_ent *make_ogg_entry(request_rec *r, apr_pool_t *pool, FILE *const in,
	const mu_config *const conf, mu_ent_names *const names);
#endif
